# pyChomikuj
(W.I.P) Chomikuj API written in Python

## TODO:
- Support for Mobile API (Chomikuj Android)
- Support for Windows API (ChomikBox)
- Support for Web API (Chomikuj.pl Website)
- API documentation for every of them

## Status
This project is in very early development, here is a list of features that work as of the latest commit
1. Mobile API
- Logging in
- Searching for files
- Listing directories, including password protected ones
2. Windows API
- Nothing
3. Web API
- Nothing